========
Generate
========

This module contains classes for generating structures and occupancies, such as fully
random structures and special quasi-random structures.

.. toctree::
   :maxdepth: 2

   generate.special
   generate.groundstate
   generate.enumerate
   generate.random
